@@ -8,7 +8,7 @@ from django_master.views import MasterMixin
 
 class SettingsListView(ListView, MasterMixin):
     template_name = 'django_master/settings.html'
-    context_object_name = 'settings'
+    context_object_name = 'settings_list'
     menu_item = 'settings'
 
     def get_queryset(self):
